==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetStudies.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetStudies]
(
	@VCC Varchar(50) = NULL,
	@SearchCriteria Varchar(50) = NULL,
	@SearchExpression Varchar(50) = NULL,
	@StartDate DATETIME, 
	@EndDate DATETIME,
	@Type VARCHAR(50)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[ProcessId]						''processId'',
		[TemplateId]					''templateId'',
		[Name]							''name'',
		[Description]					''description'',
		[Status]						''status'',
		[Error]							''error'',
		[Percentage]					''percentage'',
		[StatusDescription]				''statusDescription'',
		[Type]							''type'',
		[LastQueryId]					''lastQueryId'',
		[ErrorMessage]					''errorMessage'',
		[BatchStatus]					''batchStatus'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId''
	FROM [dbo].[Study] (NOLOCK)
	WHERE [VCC] = ''' + @VCC + '''
	AND [Type] = ''' + @Type + '''
	AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
	AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
	AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [Status] desc, [CreatedDate] desc 

	SET NOCOUNT OFF
	'
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetStudies.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetStudies]
(
	@VCC Varchar(50) = NULL,
	@SearchCriteria Varchar(50) = NULL,
	@SearchExpression Varchar(50) = NULL,
	@StartDate DATETIME, 
	@EndDate DATETIME,
	@Type VARCHAR(50)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[ProcessId]						''processId'',
		[TemplateId]					''templateId'',
		[Name]							''name'',
		[Description]					''description'',
		[Type]							''type'',
		[Status]						''status'',
		[Error]							''error'',
		[Percentage]					''percentage'',
		[StatusDescription]				''statusDescription'',
		[LastQueryId]					''lastQueryId'',
		[ErrorMessage]					''errorMessage'',
		[BatchStatus]					''batchStatus'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId''
	FROM [dbo].[Study] S (NOLOCK)
	WHERE [VCC] = ''' + @VCC + '''
		AND [Type] = ''' + @Type + '''
		AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [Status] desc, [CreatedDate] desc 

	SET NOCOUNT OFF
	'
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
